#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Polygon, PolyLine, Circle, Line
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor
from rlextra.graphics.canvasadapter import DirectDrawFlowable

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Polygon(points=[55.26472,117.9412,95,133.2353,134.7353,117.9412,141.3578,68.23529,95,33.82353,48.64217,68.23529,55.26472,117.9412],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[45.3309,123.6765,95,117.9412,121.4902,110.2941,128.1127,75.88235,95,49.11765,65.19854,77.79412,45.3309,123.6765],fillColor=Color(.678431,.847059,.901961,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[68.50981,110.2941,95,121.7647,121.4902,110.2941,151.2917,62.5,95,79.70588,55.26472,72.05882,68.50981,110.2941],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[55.26472,117.9412,95,133.2353,134.7353,117.9412,141.3578,68.23529,95,33.82353,48.64217,68.23529,55.26472,117.9412],strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[45.3309,123.6765,95,117.9412,121.4902,110.2941,128.1127,75.88235,95,49.11765,65.19854,77.79412,45.3309,123.6765],strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[68.50981,110.2941,95,121.7647,121.4902,110.2941,151.2917,62.5,95,79.70588,55.26472,72.05882,68.50981,110.2941],strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,133.2353,95,136.2353,98,133.2353,95,130.2353],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[131.7353,117.9412,134.7353,120.9412,137.7353,117.9412,134.7353,114.9412],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[138.3578,68.23529,141.3578,71.23529,144.3578,68.23529,141.3578,65.23529],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,33.82353,95,36.82353,98,33.82353,95,30.82353],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[45.64217,68.23529,48.64217,71.23529,51.64217,68.23529,48.64217,65.23529],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[52.26472,117.9412,55.26472,120.9412,58.26472,117.9412,55.26472,114.9412],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(95,117.9412,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(121.4902,110.2941,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(128.1127,75.88235,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(95,49.11765,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(65.19854,77.79412,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(45.3309,123.6765,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,121.7647,95,124.7647,98,121.7647,95,118.7647],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[118.4902,110.2941,121.4902,113.2941,124.4902,110.2941,121.4902,107.2941],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[148.2917,62.5,151.2917,65.5,154.2917,62.5,151.2917,59.5],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,79.70588,95,82.70588,98,79.70588,95,76.70588],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[52.26472,72.05882,55.26472,75.05882,58.26472,72.05882,55.26472,69.05882],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[65.50981,110.2941,68.50981,113.2941,71.50981,110.2941,68.50981,107.2941],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(95,95,95,160,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,169.75)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-6.20459,-10)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': '<u>U<sup><span color="red">2</span></sup></u><br/>3'
'frags': [[12.4091796875, (ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='U', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), 'U'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), '2')], [0, (ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[]), '')], [6.3623046875, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='3', textColor=Color(0,0,0,1), us_lines=[]), '3')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 12.4091796875
'_wrapWidths': [12.4091796875, 12.4091796875]
'_width_max': 12.4091796875
'height': 20.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=True, maxWidth=12.4091796875, sFW=0, wordCount=1, words=[ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='U', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[])]), FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=6.046875, fontSize=10, lineBreak=False, maxWidth=12.4091796875, sFW=1, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='3', textColor=Color(0,0,0,1), us_lines=[])])])
) #Paragraph))
		self.add(Line(95,95,151.2917,127.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,159.7354,132.375)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-5.965332,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'V<sup><span color="red">3</span></sup>'
'frags': [[11.9306640625, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='V', textColor=Color(0,0,0,1), us_lines=[]), 'V'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='3', textColor=Color(1,0,0,1), us_lines=[]), '3')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 11.9306640625
'_wrapWidths': [11.9306640625, 11.9306640625]
'_width_max': 11.9306640625
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=False, maxWidth=11.9306640625, sFW=0, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='V', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='3', textColor=Color(1,0,0,1), us_lines=[])])])
) #Paragraph))
		self.add(Line(95,95,151.2917,62.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,159.7354,57.625)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-4.943848,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'W'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='W', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 9.8876953125
'_wrapWidths': [9.8876953125, 9.8876953125]
'_width_max': 9.8876953125
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['W'])], link=[], rise=0, text='W', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		self.add(Line(95,95,95,30,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,20.25)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-3.425293,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'X'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='X', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 6.8505859375
'_wrapWidths': [6.8505859375, 6.8505859375]
'_width_max': 6.8505859375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['X'])], link=[], rise=0, text='X', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		self.add(Line(95,95,38.70835,62.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,30.2646,57.625)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-3.054199,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Y'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Y', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 6.1083984375
'_wrapWidths': [6.1083984375, 6.1083984375]
'_width_max': 6.1083984375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['Y'])], link=[], rise=0, text='Y', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		self.add(Line(95,95,38.70835,127.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,30.2646,132.375)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-3.425293,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Z'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Z', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 6.8505859375
'_wrapWidths': [6.8505859375, 6.8505859375]
'_width_max': 6.8505859375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['Z'])], link=[], rise=0, text='Z', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,128.2353)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-10.81543,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'zero'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='zero', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 21.630859375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483625.3691406, ['zero'])], link=[], rise=0, text='zero', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,130.4052,115.4412)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-9.304199,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'one'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='one', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 18.6083984375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483628.3916016, ['one'])], link=[], rise=0, text='one', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,38.82353)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-17.44629,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'special'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='special', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 34.892578125
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483612.1074219, ['special'])], link=[], rise=0, text='special', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,110.9412)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-15.95312,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Earth<sup>1</sup>'
'frags': [[31.90625, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Earth', textColor=Color(0,0,0,1), us_lines=[]), 'Earth'), (ParaFrag(__tag__='super', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='1', textColor=Color(0,0,0,1), us_lines=[]), '1')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 31.90625
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=2147483615.09375, fontSize=10, lineBreak=False, maxWidth=2147483647, sFW=0, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Earth', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='1', textColor=Color(0,0,0,1), us_lines=[])])])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,146.9615,65)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-12.03857,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Mars'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Mars', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 24.0771484375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483622.9228516, ['Mars'])], link=[], rise=0, text='Mars', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Polygon, Line, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=100,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Polygon(points=(110,12.125,114.25,16.375,114.25,24.875,110,20.625),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,20.625,24.25,24.875,114.25,24.875,110,20.625),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,12.125,110,12.125,110,20.625,20,20.625),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,20.625,110,20.625,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(140,33.375,144.25,37.625,144.25,46.125,140,41.875),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,41.875,24.25,46.125,144.25,46.125,140,41.875),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,33.375,140,33.375,140,41.875,20,41.875),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,41.875,140,41.875,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(50,41.875,54.25,46.125,54.25,54.625,50,50.375),fillColor=Color(0,.276078,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,50.375,24.25,54.625,54.25,54.625,50,50.375),fillColor=Color(0,.38902,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,41.875,50,41.875,50,50.375,20,50.375),fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,50.375,50,50.375,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(170,54.625,174.25,58.875,174.25,67.375,170,63.125),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,63.125,24.25,67.375,174.25,67.375,170,63.125),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,54.625,170,54.625,170,63.125,20,63.125),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,63.125,170,63.125,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(65,63.125,69.25,67.375,69.25,75.875,65,71.625),fillColor=Color(0,.276078,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,71.625,24.25,75.875,69.25,75.875,65,71.625),fillColor=Color(0,.38902,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,63.125,65,63.125,65,71.625,20,71.625),fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,71.625,65,71.625,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(200,75.875,204.25,80.125,204.25,88.625,200,84.375),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,84.375,24.25,88.625,204.25,88.625,200,84.375),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,75.875,200,75.875,200,84.375,20,84.375),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,84.375,200,84.375,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(80,84.375,84.25,88.625,84.25,97.125,80,92.875),fillColor=Color(0,.276078,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,92.875,24.25,97.125,84.25,97.125,80,92.875),fillColor=Color(0,.38902,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(20,84.375,80,84.375,80,92.875,20,92.875),fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,92.875,80,92.875,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,15,10,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,31.25,15,31.25,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,52.5,15,52.5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,73.75,15,73.75,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,95,15,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,200,10,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,10,50,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(80,10,80,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(110,10,110,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(140,10,140,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(170,10,170,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(200,10,200,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,20,5)
		v0.add(String(-5,-10,'70',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,50,5)
		v0.add(String(-5,-10,'80',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,80,5)
		v0.add(String(-5,-10,'90',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,110,5)
		v0.add(String(-7.5,-10,'100',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,140,5)
		v0.add(String(-7.5,-10,'110',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,170,5)
		v0.add(String(-7.5,-10,'120',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,200,5)
		v0.add(String(-7.5,-10,'130',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Line, String, PolyLine, Circle
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=100,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Line(20,10,190,10,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(41.25,10,41.25,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(62.5,10,62.5,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(83.75,10,83.75,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(105,10,105,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(126.25,10,126.25,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(147.5,10,147.5,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(168.75,10,168.75,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(190,10,190,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,22.14286,15,22.14286,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,42.38095,15,42.38095,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,62.61905,15,62.61905,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,82.85714,15,82.85714,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,22.14286)
		v0.add(String(-10,-4,'10',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,42.38095)
		v0.add(String(-10,-4,'20',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,62.61905)
		v0.add(String(-10,-4,'30',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,82.85714)
		v0.add(String(-10,-4,'40',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(PolyLine(points=[30.625,28.21429,51.875,12.02381,73.125,42.38095,94.375,46.42857,115.625,76.78571,136.875,92.97619,158.125,40.35714,179.375,10],strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(30.625,28.21429,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(51.875,12.02381,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(73.125,42.38095,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(94.375,46.42857,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(115.625,76.78571,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(136.875,92.97619,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(158.125,40.35714,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(179.375,10,2.5,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[30.625,30.2381,51.875,22.14286,73.125,44.40476,94.375,58.57143,115.625,78.80952,136.875,95,158.125,52.5,179.375,12.02381],strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(30.625,30.2381,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(51.875,22.14286,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(73.125,44.40476,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(94.375,58.57143,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(115.625,78.80952,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(136.875,95,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(158.125,52.5,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(179.375,12.02381,2.5,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Polygon, Line, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=100,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Polygon(points=(42.5,10,51.5,19,51.5,61.5,42.5,52.5),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(24.5,52.5,33.5,61.5,51.5,61.5,42.5,52.5),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(24.5,10,42.5,10,42.5,52.5,24.5,52.5),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(24.5,52.5,42.5,52.5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(87.5,10,96.5,19,96.5,75.66667,87.5,66.66667),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(69.5,66.66667,78.5,75.66667,96.5,75.66667,87.5,66.66667),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(69.5,10,87.5,10,87.5,66.66667,69.5,66.66667),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(69.5,66.66667,87.5,66.66667,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(105.5,10,114.5,19,114.5,33.16667,105.5,24.16667),fillColor=Color(0,.276078,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(87.5,24.16667,96.5,33.16667,114.5,33.16667,105.5,24.16667),fillColor=Color(0,.38902,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(87.5,10,105.5,10,105.5,24.16667,87.5,24.16667),fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(87.5,24.16667,105.5,24.16667,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(132.5,10,141.5,19,141.5,89.83333,132.5,80.83333),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(114.5,80.83333,123.5,89.83333,141.5,89.83333,132.5,80.83333),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(114.5,10,132.5,10,132.5,80.83333,114.5,80.83333),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(114.5,80.83333,132.5,80.83333,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(150.5,10,159.5,19,159.5,40.25,150.5,31.25),fillColor=Color(0,.276078,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(132.5,31.25,141.5,40.25,159.5,40.25,150.5,31.25),fillColor=Color(0,.38902,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(132.5,10,150.5,10,150.5,31.25,132.5,31.25),fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(132.5,31.25,150.5,31.25,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(177.5,10,186.5,19,186.5,104,177.5,95),fillColor=Color(.55,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(159.5,95,168.5,104,186.5,104,177.5,95),fillColor=Color(.775,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(159.5,10,177.5,10,177.5,95,159.5,95),fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(159.5,95,177.5,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(195.5,10,204.5,19,204.5,47.33333,195.5,38.33333),fillColor=Color(0,.276078,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(177.5,38.33333,186.5,47.33333,204.5,47.33333,195.5,38.33333),fillColor=Color(0,.38902,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=(177.5,10,195.5,10,195.5,38.33333,177.5,38.33333),fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(177.5,38.33333,195.5,38.33333,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,200,10,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(65,10,65,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(110,10,110,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(155,10,155,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(200,10,200,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,15,10,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,24.16667,15,24.16667,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,38.33333,15,38.33333,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,52.5,15,52.5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,66.66667,15,66.66667,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,80.83333,15,80.83333,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,95,15,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,10)
		v0.add(String(-10,-4,'70',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,24.16667)
		v0.add(String(-10,-4,'80',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,38.33333)
		v0.add(String(-10,-4,'90',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,52.5)
		v0.add(String(-15,-4,'100',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,66.66667)
		v0.add(String(-15,-4,'110',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,80.83333)
		v0.add(String(-15,-4,'120',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,15,95)
		v0.add(String(-15,-4,'130',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Line, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=100,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(20,12.125,90,8.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,33.375,120,8.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,54.625,150,8.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,75.875,180,8.5,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,41.875,30,8.5,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,63.125,45,8.5,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,84.375,60,8.5,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,15,10,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,31.25,15,31.25,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,52.5,15,52.5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,73.75,15,73.75,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,95,15,95,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,200,10,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(20,10,20,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,10,50,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(80,10,80,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(110,10,110,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(140,10,140,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(170,10,170,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(200,10,200,5,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,20,5)
		v0.add(String(-5,-10,'70',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,50,5)
		v0.add(String(-5,-10,'80',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,80,5)
		v0.add(String(-5,-10,'90',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,110,5)
		v0.add(String(-7.5,-10,'100',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,140,5)
		v0.add(String(-7.5,-10,'110',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,170,5)
		v0.add(String(-7.5,-10,'120',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,200,5)
		v0.add(String(-7.5,-10,'130',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Wedge
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor
from rlextra.graphics.canvasadapter import DirectDrawFlowable

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Wedge(95,95,65,-90,90,yradius=65,annular=False,fillColor=Color(0,.545098,.545098,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=26,yradius1=26))
		self.add(Wedge(95,95,65,-270,-90,yradius=65,annular=False,fillColor=Color(.541176,.168627,.886275,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=26,yradius1=26))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,173,95)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,0,-10)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': '<u>a<sup><span color="red">2</span></sup></u><br/>2'
'frags': [[11.2177734375, (ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='a', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), 'a'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), '2')], [0, (ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[]), '')], [6.3623046875, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='2', textColor=Color(0,0,0,1), us_lines=[]), '2')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 11.2177734375
'_wrapWidths': [11.2177734375, 11.2177734375]
'_width_max': 11.2177734375
'height': 20.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=True, maxWidth=11.2177734375, sFW=0, wordCount=1, words=[ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='a', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[])]), FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=4.85546875, fontSize=10, lineBreak=False, maxWidth=11.2177734375, sFW=1, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='2', textColor=Color(0,0,0,1), us_lines=[])])])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,17,95)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-11.4375,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'b<sup><span color="red">2</span></sup>'
'frags': [[11.4375, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='b', textColor=Color(0,0,0,1), us_lines=[]), 'b'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[]), '2')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 11.4375
'_wrapWidths': [11.4375, 11.4375]
'_width_max': 11.4375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=False, maxWidth=11.4375, sFW=0, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='b', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[])])])
) #Paragraph))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
